#include "ex94317demo.h"
#include "ui_ex94317demo.h"

u8 CardID ;
u32 Status ;
int fd ;

struct ChkByte{
        unsigned bit0:1;
        unsigned bit1:1;
        unsigned bit2:1;
        unsigned bit3:1;
        unsigned bit4:1;
        unsigned bit5:1;
        unsigned bit6:1;
        unsigned bit7:1;
};
union ByteData
{
        ChkByte _ByteData;
        u8 data;
};

// ------------ constructor & destructor ---------------
ex94317demo::ex94317demo(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::ex94317demo)
{
    ui->setupUi(this);
    int port = 0;
    int point = 0;
    config_data = 0;

    QCheckBox *temp_Port_checkBox[6][8] = { {this->ui->Port00_checkBox, this->ui->Port01_checkBox, this->ui->Port02_checkBox, this->ui->Port03_checkBox,
                                             this->ui->Port04_checkBox, this->ui->Port05_checkBox, this->ui->Port06_checkBox, this->ui->Port07_checkBox},

                                            {this->ui->Port10_checkBox, this->ui->Port11_checkBox, this->ui->Port12_checkBox, this->ui->Port13_checkBox,
                                           this->ui->Port14_checkBox, this->ui->Port15_checkBox, this->ui->Port16_checkBox, this->ui->Port17_checkBox},

                                            {this->ui->Port20_checkBox, this->ui->Port21_checkBox, this->ui->Port22_checkBox, this->ui->Port23_checkBox,
                                           this->ui->Port24_checkBox, this->ui->Port25_checkBox, this->ui->Port26_checkBox, this->ui->Port27_checkBox},

                                            {this->ui->Port30_checkBox, this->ui->Port31_checkBox, this->ui->Port32_checkBox, this->ui->Port33_checkBox,
                                           this->ui->Port34_checkBox, this->ui->Port35_checkBox, this->ui->Port36_checkBox, this->ui->Port37_checkBox},

                                            {this->ui->Port40_checkBox, this->ui->Port41_checkBox, this->ui->Port42_checkBox, this->ui->Port43_checkBox,
                                           this->ui->Port44_checkBox, this->ui->Port45_checkBox, this->ui->Port46_checkBox, this->ui->Port47_checkBox},

                                            {this->ui->Port50_checkBox, this->ui->Port51_checkBox, this->ui->Port52_checkBox, this->ui->Port53_checkBox,
                                           this->ui->Port54_checkBox, this->ui->Port55_checkBox, this->ui->Port56_checkBox, this->ui->Port57_checkBox}  };

    QComboBox *temp_Debounce_comboBox[6] = { this->ui->Debounce0_comboBox, this->ui->Debounce1_comboBox, this->ui->Debounce2_comboBox,
                                             this->ui->Debounce3_comboBox, this->ui->Debounce4_comboBox, this->ui->Debounce5_comboBox };
    QComboBox *temp_IOConfig_comboBox[6] = { this->ui->IOConfig0_comboBox, this->ui->IOConfig1_comboBox, this->ui->IOConfig2_comboBox,
                                             this->ui->IOConfig3_comboBox, this->ui->IOConfig4_comboBox, this->ui->IOConfig5_comboBox };

    for ( port = 0; port < 6; port++  )
    {
        for ( point = 0; point < MAX_POINT_NUM; point++  )
        {
            this->Port_checkBox[port][point] = temp_Port_checkBox[port][point];
        }

        this->Debounce_comboBox[port] = temp_Debounce_comboBox[port];
        this->IOConfig_comboBox[port] = temp_IOConfig_comboBox[port];
    }

    // initial
    Status = 0;
    u8 data = 0;
    u8 config_data = 0;
    int temp = 0;


    this->initial_failed = false;
    this->initial_card();
    if ( true == this->initial_failed )
      {
        this->close_timer = 0;
        this->close_timer = startTimer(300);
      }

    for ( port = 0; port < 6; port++  )
    {
        Status = EX94317_debounce_time_read( CardID , port, &data );
        this->Debounce_comboBox[port]->setCurrentIndex(data);
    }

    this->io_config_read();

    this->main_timer = startTimer(100);

    // create menu action
    this->ui->menuQuit->addAction(this->ui->actionExit);
    this->ui->menuFunction->addAction(this->ui->actionTimer);
    this->ui->menuFunction->addAction(this->ui->actionInterrupt);

    // create new form
    this->form_Timer = new Timer_Form(0, Qt::Sheet);
    this->form_Interrupt = new Interrupt_Form(0, Qt::Sheet);
}

ex94317demo::~ex94317demo()
{
    delete ui;
}




// ------------ event ---------------
void ex94317demo::timerEvent ( QTimerEvent *event )
{
    // qWarning("test");
    if ( event->timerId() == this->close_timer )    // when initial failed
      {
        this->close();
        killTimer( this->close_timer );
      }
    if ( event->timerId() == this->main_timer )    // when initial failed
      {
        this->io_point_read();
        if ( Status != 0 )
        {
            this->ui->ErrorNum_label->setText( QString::number(Status, 10) );
        }
      }


}
void ex94317demo::closeEvent ( QCloseEvent *event )
{
    EX94317_IRQ_disable( CardID );
    EX94317_close( fd );
    event->accept();
}





// ------------ sub-function ---------------
void ex94317demo::initial_card()
{
    int id_index = 0;
    u16 base_address = 0;
    u16 tc_address = 0;

    const int irq_mask = 255;

    Status = EX94317_initial( &fd );
    if ( Status != DRV_NO_ERROR )       // Exception process
    {
        switch( QMessageBox::warning( this, QString::fromUtf8 ("EX94317"),
                                      QString::fromUtf8 ("Initial fail!") + "\n" + "Error #" + QString::number(Status,10),
                                      QMessageBox::Ok, QMessageBox::NoButton, QMessageBox::NoButton ) )
        {
        case QMessageBox::Ok: 		// first button in message box
        {
            // force to exit
        }
        default:
        {
            this->initial_failed = true;
            break;
        }
        }
    }

    for ( id_index = 0; id_index <= _CARD_ID_MAX; id_index++ )
    {
        Status = EX94317_info( id_index, &base_address, &tc_address);
        if ( DRV_NO_ERROR == Status )
        {
            this->ui->ID_comboBox->addItem( QString::number(id_index,10) );
            CardID = id_index;
            this->ui->Address_label->setText( "Address: " + QString::number(base_address,16) + "-" + QString::number(tc_address,16) + "(H)" );
        }
    }
}

void ex94317demo::io_config_read()
{
    int port = 0, point = 0;
    u8 config = 0;

    Status = EX94317_config_read( CardID, &this->config_data );
    for ( port = 0; port < 6; port++  )
    {
        config = (this->config_data >> port) & 1;
//        qWarning("config %d",config );
        this->IOConfig_comboBox[port]->setCurrentIndex( config );
        io_rename( port, config );
    }
}

void ex94317demo::io_rename(int port, int index)
{
    int point = 0;

    if ( 0 == index )   // set input
    {
        for ( point = 0; point < 8; point++  )
        {
            this->Port_checkBox[port][point]->setText("INPUT" + QString::number(port, 10) + " " + QString::number(point, 10));

        }
    }
    else if ( 1 == index )  // set output
    {
        for ( point = 0; point < 8; point++  )
        {
                this->Port_checkBox[port][point]->setText("OUTPUT" + QString::number(port, 10) + " " + QString::number(point, 10));
        }
    }
}

void ex94317demo::io_point_read()
{
    int port = 0, point = 0;
    u8 state = 0;

    for ( port = 0; port < 6; port++  )
    {
        for ( point = 0; point < MAX_POINT_NUM; point++  )
        {
            Status = EX94317_point_read( CardID, port, point, &state );
            if ( true == state )
            {
                this->Port_checkBox[port][point]->setChecked(true);
            }
            else
            {
                this->Port_checkBox[port][point]->setChecked(false);
            }

        }
    }
}




// ------------ slot ---------------
void ex94317demo::on_Exit_pushButton_clicked()
{
    this->close();
}

//-debounce
void ex94317demo::on_Debounce0_comboBox_currentIndexChanged(int index)
{
    int port = 0;
    Status = EX94317_debounce_time_set( CardID, port, index );
}
void ex94317demo::on_Debounce1_comboBox_currentIndexChanged(int index)
{
    int port = 1;
    Status = EX94317_debounce_time_set( CardID, port, index );
}
void ex94317demo::on_Debounce2_comboBox_currentIndexChanged(int index)
{
    int port = 2;
    Status = EX94317_debounce_time_set( CardID, port, index );
}
void ex94317demo::on_Debounce3_comboBox_currentIndexChanged(int index)
{
    int port = 3;
    Status = EX94317_debounce_time_set( CardID, port, index );
}
void ex94317demo::on_Debounce4_comboBox_currentIndexChanged(int index)
{
    int port = 4;
    Status = EX94317_debounce_time_set( CardID, port, index );
}
void ex94317demo::on_Debounce5_comboBox_currentIndexChanged(int index)
{
    int port = 5;
    Status = EX94317_debounce_time_set( CardID, port, index );
}
//-IO_config
void ex94317demo::on_IOConfig0_comboBox_currentIndexChanged(int index)
{
    int port = 0;
    ByteData config;
    config.data = this->config_data;
    config._ByteData.bit0 = index;
    Status = EX94317_config_set( CardID, config.data );
    this->io_rename(port, index);
    this->config_data = config.data;
}
void ex94317demo::on_IOConfig1_comboBox_currentIndexChanged(int index)
{
    int port = 1;
    ByteData config;
    config.data = this->config_data;
    config._ByteData.bit1 = index;
    Status = EX94317_config_set( CardID, config.data );
    this->io_rename(port, index);
    this->config_data = config.data;
}
void ex94317demo::on_IOConfig2_comboBox_currentIndexChanged(int index)
{
    int port = 2;
    ByteData config;
    config.data = this->config_data;
    config._ByteData.bit2 = index;
    Status = EX94317_config_set( CardID, config.data );
    this->io_rename(port, index);
    this->config_data = config.data;
}
void ex94317demo::on_IOConfig3_comboBox_currentIndexChanged(int index)
{
    int port = 3;
    ByteData config;
    config.data = this->config_data;
    config._ByteData.bit3 = index;
    Status = EX94317_config_set( CardID, config.data );
    this->io_rename(port, index);
    this->config_data = config.data;
}
void ex94317demo::on_IOConfig4_comboBox_currentIndexChanged(int index)
{
    int port = 4;
    ByteData config;
    config.data = this->config_data;
    config._ByteData.bit4 = index;
    Status = EX94317_config_set( CardID, config.data );
    this->io_rename(port, index);
    this->config_data = config.data;
}
void ex94317demo::on_IOConfig5_comboBox_currentIndexChanged(int index)
{
    int port = 5;
    ByteData config;
    config.data = this->config_data;
    config._ByteData.bit5 = index;
    Status = EX94317_config_set( CardID, config.data );
    this->io_rename(port, index);
    this->config_data = config.data;
}



void ex94317demo::on_Port00_checkBox_clicked(bool checked)
{
    u8 port = 0 ;
    u8 point = 0 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}

void ex94317demo::on_Port01_checkBox_clicked(bool checked)
{
    u8 port = 0 ;
    u8 point = 1 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port02_checkBox_clicked(bool checked)
{
    u8 port = 0 ;
    u8 point = 2 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port03_checkBox_clicked(bool checked)
{
    u8 port = 0 ;
    u8 point = 3 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port04_checkBox_clicked(bool checked)
{
    u8 port = 0 ;
    u8 point = 4 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port05_checkBox_clicked(bool checked)
{
    u8 port = 0 ;
    u8 point = 5 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port06_checkBox_clicked(bool checked)
{
    u8 port = 0 ;
    u8 point = 6 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port07_checkBox_clicked(bool checked)
{
    u8 port = 0 ;
    u8 point = 7 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}

void ex94317demo::on_Port10_checkBox_clicked(bool checked)
{
    u8 port = 1 ;
    u8 point = 0 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port11_checkBox_clicked(bool checked)
{
    u8 port = 1 ;
    u8 point = 1 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port12_checkBox_clicked(bool checked)
{
    u8 port = 1 ;
    u8 point = 2 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port13_checkBox_clicked(bool checked)
{
    u8 port = 1 ;
    u8 point = 3 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port14_checkBox_clicked(bool checked)
{
    u8 port = 1 ;
    u8 point = 4 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port15_checkBox_clicked(bool checked)
{
    u8 port = 1 ;
    u8 point = 5 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port16_checkBox_clicked(bool checked)
{
    u8 port = 1 ;
    u8 point = 6 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port17_checkBox_clicked(bool checked)
{
    u8 port = 1 ;
    u8 point = 7 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}

void ex94317demo::on_Port20_checkBox_clicked(bool checked)
{
    u8 port = 2 ;
    u8 point = 0 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port21_checkBox_clicked(bool checked)
{
    u8 port = 2 ;
    u8 point = 1 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port22_checkBox_clicked(bool checked)
{
    u8 port = 2 ;
    u8 point = 2 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port23_checkBox_clicked(bool checked)
{
    u8 port = 2 ;
    u8 point = 3 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port24_checkBox_clicked(bool checked)
{
    u8 port = 2 ;
    u8 point = 4 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port25_checkBox_clicked(bool checked)
{
    u8 port = 2 ;
    u8 point = 5 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port26_checkBox_clicked(bool checked)
{
    u8 port = 2 ;
    u8 point = 6 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port27_checkBox_clicked(bool checked)
{
    u8 port = 2 ;
    u8 point = 7 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}

void ex94317demo::on_Port30_checkBox_clicked(bool checked)
{
    u8 port = 3 ;
    u8 point = 0 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port31_checkBox_clicked(bool checked)
{
    u8 port = 3 ;
    u8 point = 1 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port32_checkBox_clicked(bool checked)
{
    u8 port = 3 ;
    u8 point = 2 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port33_checkBox_clicked(bool checked)
{
    u8 port = 3 ;
    u8 point = 3 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port34_checkBox_clicked(bool checked)
{
    u8 port = 3 ;
    u8 point = 4 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port35_checkBox_clicked(bool checked)
{
    u8 port = 3 ;
    u8 point = 5 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port36_checkBox_clicked(bool checked)
{
    u8 port = 3 ;
    u8 point = 6 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port37_checkBox_clicked(bool checked)
{
    u8 port = 3 ;
    u8 point = 7 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}

void ex94317demo::on_Port40_checkBox_clicked(bool checked)
{
    u8 port = 4 ;
    u8 point = 0 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port41_checkBox_clicked(bool checked)
{
    u8 port = 4 ;
    u8 point = 1 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port42_checkBox_clicked(bool checked)
{
    u8 port = 4 ;
    u8 point = 2 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port43_checkBox_clicked(bool checked)
{
    u8 port = 4 ;
    u8 point = 3 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port44_checkBox_clicked(bool checked)
{
    u8 port = 4 ;
    u8 point = 4 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port45_checkBox_clicked(bool checked)
{
    u8 port = 4 ;
    u8 point = 5 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port46_checkBox_clicked(bool checked)
{
    u8 port = 4 ;
    u8 point = 6 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port47_checkBox_clicked(bool checked)
{
    u8 port = 4 ;
    u8 point = 7 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}

void ex94317demo::on_Port50_checkBox_clicked(bool checked)
{
    u8 port = 5 ;
    u8 point = 0 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port51_checkBox_clicked(bool checked)
{
    u8 port = 5 ;
    u8 point = 1 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port52_checkBox_clicked(bool checked)
{
    u8 port = 5 ;
    u8 point = 2 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port53_checkBox_clicked(bool checked)
{
    u8 port = 5 ;
    u8 point = 3 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port54_checkBox_clicked(bool checked)
{
    u8 port = 5 ;
    u8 point = 4 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port55_checkBox_clicked(bool checked)
{
    u8 port = 5 ;
    u8 point = 5 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port56_checkBox_clicked(bool checked)
{
    u8 port = 5 ;
    u8 point = 6 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}
void ex94317demo::on_Port57_checkBox_clicked(bool checked)
{
    u8 port = 5 ;
    u8 point = 7 ;

    if( ACTIVE == checked )
    {
        Status = EX94317_point_set( CardID, port, point, ACTIVE );
    }
    else
    {
        Status = EX94317_point_set( CardID, port, point, INACTIVE );
    }
}

void ex94317demo::on_actionExit_triggered()
{
    this->close();
}

void ex94317demo::on_actionInterrupt_triggered()
{
    this->form_Interrupt->show();
}

void ex94317demo::on_actionTimer_triggered()
{
    this->form_Timer->show();
}
