#include "interrupt_form.h"
#include "ui_interrupt_form.h"

struct ChkByte{
        unsigned bit0:1;
        unsigned bit1:1;
        unsigned bit2:1;
        unsigned bit3:1;
        unsigned bit4:1;
        unsigned bit5:1;
        unsigned bit6:1;
        unsigned bit7:1;
};
union ByteData
{
        ChkByte _ByteData;
        u8 data;
};

u32 irq_counter = 0 ;
void call_back(u8 Card_ID)
{
    qWarning("test_irq_process %d", Card_ID);
    irq_counter++;
}

// ------------ constructor & destructor ---------------
Interrupt_Form::Interrupt_Form(QWidget *parent, Qt::WindowFlags fl ):
    QWidget(parent, fl),
    ui(new Ui::Interrupt_Form)
{
    ui->setupUi(this);
    this->is_fomr_started = false;
    int index = 0;
    this->irq_mask = 0;
    this->irq_polarity = 0;

    QCheckBox *temp_Mask_checkBox[] = { this->ui->Mask00_checkBox, this->ui->Mask01_checkBox, this->ui->Mask02_checkBox, this->ui->Mask03_checkBox,
                                        this->ui->Mask04_checkBox, this->ui->Mask05_checkBox, this->ui->Mask06_checkBox, this->ui->Mask07_checkBox };
    QCheckBox *temp_Status_checkBox[] = { this->ui->Status00_checkBox, this->ui->Status01_checkBox, this->ui->Status02_checkBox, this->ui->Status03_checkBox,
                                          this->ui->Status04_checkBox, this->ui->Status05_checkBox, this->ui->Status06_checkBox, this->ui->Status07_checkBox };
    QCheckBox *temp_Polarity_checkBox[] = { this->ui->Polarity00_checkBox, this->ui->Polarity01_checkBox, this->ui->Polarity02_checkBox, this->ui->Polarity03_checkBox,
                                            this->ui->Polarity04_checkBox, this->ui->Polarity05_checkBox, this->ui->Polarity06_checkBox, this->ui->Polarity07_checkBox };

    for( index = 0; index < MAX_POINT_NUM ; index++ )
      {
        this->Mask_checkBox[ index ] = temp_Mask_checkBox[ index ];
        this->Status_checkBox[ index ] = temp_Status_checkBox[ index ];
        this->Polarity_checkBox[ index ] = temp_Polarity_checkBox[ index ];
      }
}

Interrupt_Form::~Interrupt_Form()
{
    delete ui;
}




// ------------ event ---------------
void Interrupt_Form::showEvent(QShowEvent *)
{
    qWarning("showEvent");

    if ( false == this->is_fomr_started )
    {
        this->mask_read();
        this->status_read();
        this->polarity_read();

        this->interrupt_timer = startTimer( 100 );
        this->is_fomr_started = true;
    }
}

void Interrupt_Form::timerEvent ( QTimerEvent *event )
{
    // qWarning("test");
    if ( event->timerId() == this->interrupt_timer )
    {
        this->status_read();
        this->ui->IrqCounter_label->setText("IRQ Counter: "+ QString::number(irq_counter,10) );
    }
}

void Interrupt_Form::closeEvent ( QCloseEvent *event )
{
    killTimer(this->interrupt_timer);
    this->interrupt_timer = 0;
    this->is_fomr_started = false;
    Status = EX94317_IRQ_disable( CardID );

    event->accept();
}




// ------------ sub-function ---------------
void Interrupt_Form::mask_read()
{
    u8 point = 0;
    u8 tc_mask = 0;
    u8 state = 0;

    Status = EX94317_IRQ_mask_read( CardID, 0, &this->irq_mask );
    for ( point = 0; point < MAX_POINT_NUM; point++ )
    {
        state = ( this->irq_mask >> point ) & 1;
        if ( ACTIVE == state )
        {
            this->Mask_checkBox[point]->setChecked(true);
        }
        else
        {
            this->Mask_checkBox[point]->setChecked(false);
        }
    }

    Status = EX94317_IRQ_mask_read( CardID, 1, &tc_mask );
    if ( ACTIVE == tc_mask )
    {
        this->ui->TCMask_checkBox->setChecked(true);
    }
    else
    {
        this->ui->TCMask_checkBox->setChecked(false);
    }
}

void Interrupt_Form::status_read()
{
    u8 point = 0;
    u8 irq_status = 0;
    u8 state = 0;

    Status = EX94317_IRQ_status_read( CardID, 0, &irq_status );
    for ( point = 0; point < MAX_POINT_NUM; point++ )
    {
        state = ( irq_status >> point ) & 1;
        if ( ACTIVE == state )
        {
            this->Status_checkBox[point]->setChecked(true);
        }
        else
        {
            this->Status_checkBox[point]->setChecked(false);
        }
    }

    Status = EX94317_IRQ_status_read( CardID, 1, &irq_status );
    if ( ACTIVE == irq_status )
    {
        this->ui->TCStatus_checkBox->setChecked(true);
    }
    else
    {
        this->ui->TCStatus_checkBox->setChecked(false);
    }
}

void Interrupt_Form::polarity_read()
{
    u8 point = 0;
    u8 state = 0;

    Status = EX94317_IRQ_polarity_read( CardID, &this->irq_polarity );
    for ( point = 0; point < MAX_POINT_NUM; point++ )
    {
        state = ( this->irq_polarity >> point ) & 1;
        if ( ACTIVE == state )
        {
            this->Polarity_checkBox[point]->setChecked(true);
        }
        else
        {
            this->Polarity_checkBox[point]->setChecked(false);
        }
    }

}




// ------------ slot ---------------
void Interrupt_Form::on_Mask00_checkBox_clicked(bool checked)
{
    u8 bit = 0;
    ByteData mask_data;
    mask_data.data = this->irq_mask;

    if ( true == checked )  bit = 1;
    else                   bit = 0;

    mask_data._ByteData.bit0 = bit;
    Status = EX94317_IRQ_mask_set( CardID, 0, mask_data.data );

    this->irq_mask = mask_data.data;
}
void Interrupt_Form::on_Mask01_checkBox_clicked(bool checked)
{
    u8 bit = 0;
    ByteData mask_data;
    mask_data.data = this->irq_mask;

    if ( true == checked )  bit = 1;
    else                   bit = 0;

    mask_data._ByteData.bit1 = bit;
    Status = EX94317_IRQ_mask_set( CardID, 0, mask_data.data );

    this->irq_mask = mask_data.data;
}
void Interrupt_Form::on_Mask02_checkBox_clicked(bool checked)
{
    u8 bit = 0;
    ByteData mask_data;
    mask_data.data = this->irq_mask;

    if ( true == checked )  bit = 1;
    else                   bit = 0;

    mask_data._ByteData.bit2 = bit;
    Status = EX94317_IRQ_mask_set( CardID, 0, mask_data.data );

    this->irq_mask = mask_data.data;
}
void Interrupt_Form::on_Mask03_checkBox_clicked(bool checked)
{
    u8 bit = 0;
    ByteData mask_data;
    mask_data.data = this->irq_mask;

    if ( true == checked )  bit = 1;
    else                   bit = 0;

    mask_data._ByteData.bit3 = bit;
    Status = EX94317_IRQ_mask_set( CardID, 0, mask_data.data );

    this->irq_mask = mask_data.data;
}
void Interrupt_Form::on_Mask04_checkBox_clicked(bool checked)
{
    u8 bit = 0;
    ByteData mask_data;
    mask_data.data = this->irq_mask;

    if ( true == checked )  bit = 1;
    else                   bit = 0;

    mask_data._ByteData.bit4 = bit;
    Status = EX94317_IRQ_mask_set( CardID, 0, mask_data.data );

    this->irq_mask = mask_data.data;
}
void Interrupt_Form::on_Mask05_checkBox_clicked(bool checked)
{
    u8 bit = 0;
    ByteData mask_data;
    mask_data.data = this->irq_mask;

    if ( true == checked )  bit = 1;
    else                   bit = 0;

    mask_data._ByteData.bit5 = bit;
    Status = EX94317_IRQ_mask_set( CardID, 0, mask_data.data );

    this->irq_mask = mask_data.data;
}
void Interrupt_Form::on_Mask06_checkBox_clicked(bool checked)
{
    u8 bit = 0;
    ByteData mask_data;
    mask_data.data = this->irq_mask;

    if ( true == checked )  bit = 1;
    else                   bit = 0;

    mask_data._ByteData.bit6 = bit;
    Status = EX94317_IRQ_mask_set( CardID, 0, mask_data.data );

    this->irq_mask = mask_data.data;
}
void Interrupt_Form::on_Mask07_checkBox_clicked(bool checked)
{
    u8 bit = 0;
    ByteData mask_data;
    mask_data.data = this->irq_mask;

    if ( true == checked )  bit = 1;
    else                   bit = 0;

    mask_data._ByteData.bit7 = bit;
    Status = EX94317_IRQ_mask_set( CardID, 0, mask_data.data );

    this->irq_mask = mask_data.data;
}
//-------------------- Set Polarity -------------------------
void Interrupt_Form::on_Polarity00_checkBox_clicked(bool checked)
{
    u8 bit = 0;
    ByteData Polarity_data;
    Polarity_data.data = this->irq_polarity;

    if ( true == checked )  bit = 1;
    else                   bit = 0;

    Polarity_data._ByteData.bit0 = bit;
    Status = EX94317_IRQ_polarity_set( CardID, Polarity_data.data );

    this->irq_polarity = Polarity_data.data;
}
void Interrupt_Form:: on_Polarity01_checkBox_clicked(bool checked)
{
    u8 bit = 0;
    ByteData Polarity_data;
    Polarity_data.data = this->irq_polarity;

    if ( true == checked )  bit = 1;
    else                   bit = 0;

    Polarity_data._ByteData.bit1 = bit;
    Status = EX94317_IRQ_polarity_set( CardID, Polarity_data.data );

    this->irq_polarity = Polarity_data.data;
}
void Interrupt_Form:: on_Polarity02_checkBox_clicked(bool checked)
{
    u8 bit = 0;
    ByteData Polarity_data;
    Polarity_data.data = this->irq_polarity;

    if ( true == checked )  bit = 1;
    else                   bit = 0;

    Polarity_data._ByteData.bit2 = bit;
    Status = EX94317_IRQ_polarity_set( CardID, Polarity_data.data );

    this->irq_polarity = Polarity_data.data;
}
void Interrupt_Form:: on_Polarity03_checkBox_clicked(bool checked)
{
    u8 bit = 0;
    ByteData Polarity_data;
    Polarity_data.data = this->irq_polarity;

    if ( true == checked )  bit = 1;
    else                   bit = 0;

    Polarity_data._ByteData.bit3 = bit;
    Status = EX94317_IRQ_polarity_set( CardID, Polarity_data.data );

    this->irq_polarity = Polarity_data.data;
}
void Interrupt_Form:: on_Polarity04_checkBox_clicked(bool checked)
{
    u8 bit = 0;
    ByteData Polarity_data;
    Polarity_data.data = this->irq_polarity;

    if ( true == checked )  bit = 1;
    else                   bit = 0;

    Polarity_data._ByteData.bit4 = bit;
    Status = EX94317_IRQ_polarity_set( CardID, Polarity_data.data );

    this->irq_polarity = Polarity_data.data;
}
void Interrupt_Form:: on_Polarity05_checkBox_clicked(bool checked)
{
    u8 bit = 0;
    ByteData Polarity_data;
    Polarity_data.data = this->irq_polarity;

    if ( true == checked )  bit = 1;
    else                   bit = 0;

    Polarity_data._ByteData.bit5 = bit;
    Status = EX94317_IRQ_polarity_set( CardID, Polarity_data.data );

    this->irq_polarity = Polarity_data.data;
}
void Interrupt_Form:: on_Polarity06_checkBox_clicked(bool checked)
{
    u8 bit = 0;
    ByteData Polarity_data;
    Polarity_data.data = this->irq_polarity;

    if ( true == checked )  bit = 1;
    else                   bit = 0;

    Polarity_data._ByteData.bit6 = bit;
    Status = EX94317_IRQ_polarity_set( CardID, Polarity_data.data );

    this->irq_polarity = Polarity_data.data;
}
void Interrupt_Form:: on_Polarity07_checkBox_clicked(bool checked)
{
    u8 bit = 0;
    ByteData Polarity_data;
    Polarity_data.data = this->irq_polarity;

    if ( true == checked )  bit = 1;
    else                   bit = 0;

    Polarity_data._ByteData.bit7 = bit;
    Status = EX94317_IRQ_polarity_set( CardID, Polarity_data.data );

    this->irq_polarity = Polarity_data.data;
}

void Interrupt_Form::on_TCMask_checkBox_clicked(bool checked)
{
    u8 bit = 0;

    if ( true == checked )  bit = 1;
    else                   bit = 0;

    Status = EX94317_IRQ_mask_set( CardID, 1, bit );
    qWarning("call_back(CardID) %p", *call_back);
}

void Interrupt_Form::on_EnableIRQ_checkBox_clicked(bool checked)
{
    if ( true == checked )
    {
        qWarning("1 call_back(CardID) %p", *call_back);
        Status = EX94317_IRQ_process_link( CardID , &call_back);
        qWarning("2 call_back(CardID) %p", *call_back);
        Status = EX94317_IRQ_enable( CardID );
    }
    else
    {
        Status = EX94317_IRQ_disable( CardID );
    }
}
